CustomCursorSource

Enum CustomCursorSource 

#[non_exhaustive]
pub enum CustomCursorSource { Image(CursorImage), Animation(CursorAnimation), Url { hotspot_x: u16, hotspot_y: u16, url: String, }, }
Source for CustomCursor.

See CustomCursor for more details.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Image(CursorImage)

Cursor that is backed by RGBA image.

See CustomCursorSource::from_rgba for more.

Platform-specific
  • iOS / Android / Orbital: Unsupported


Animation(CursorAnimation)

Animated cursor.

See CustomCursorSource::from_animation for more.

Platform-specific
  • iOS / Android / Wayland / Windows / X11 / macOS / Orbital: Unsupported


Url

Creates a new cursor from a URL pointing to an image. It uses the url css function, but browser support for image formats is inconsistent. Using PNG is recommended.

Platform-specific
  • iOS / Android / Wayland / Windows / X11 / macOS / Orbital: Unsupported

Fields

hotspot_x: u16
hotspot_y: u16

Implementations

Source

impl CustomCursorSource

pub fn from_rgba( rgba: Vec<u8>, width: u16, height: u16, hotspot_x: u16, hotspot_y: u16, ) -> Result<Self, BadImage>

Creates a new cursor from an rgba buffer.

The alpha channel is assumed to be not premultiplied.

pub fn from_animation( duration: Duration, cursors: Vec<CustomCursor>, ) -> Result<Self, BadAnimation>

Crates a new animated cursor from multiple CustomCursors Supplied cursors can’t be empty or other animations.