pub struct DataTransferId(/* private fields */);Expand description
Unique identifier for a data transfer.
Implementations
Sourceimpl DataTransferId
impl DataTransferId
Sourcepub const fn into_raw(self) -> i64
pub const fn into_raw(self) -> i64
Convert the DataTransferId into the underlying integer.
This is useful if you need to pass the ID across an FFI boundary, or store it in an atomic.
Sourcepub const fn from_raw(id: i64) -> Self
pub const fn from_raw(id: i64) -> Self
Construct a DataTransferId from the underlying integer.
This should only be called with integers returned from DataTransferId::into_raw.