pub struct DragIcon {
pub icon: Icon,
pub offset_x: i32,
pub offset_y: i32,
}Expand description
Information needed to initiate a new drag operation.
Fields
icon: IconThe icon to apply to the cursor.
offset_x: i32An x offset applied to the dragged icon.
This is specified in image pixels. 0 means that the left side of the icon will be at the cursor.
offset_y: i32A y offset applied to the dragged icon.
This is specified in image pixels. 0 means that the top of the icon will be at the cursor.