pub struct WindowId(/* private fields */);Expand description
Identifier of a window. Unique for each window.
Can be obtained with window.id().
Whenever you receive an event specific to a window, this event contains a WindowId which you
can then compare to the ids of your windows.
Implementations
Sourceimpl WindowId
impl WindowId
Sourcepub const fn into_raw(self) -> usize
pub const fn into_raw(self) -> usize
Convert the WindowId into the underlying integer.
This is useful if you need to pass the ID across an FFI boundary, or store it in an atomic.
Sourcepub const fn from_raw(id: usize) -> Self
pub const fn from_raw(id: usize) -> Self
Construct a WindowId from the underlying integer.
This should only be called with integers returned from WindowId::into_raw.