PlatformWindowAttributes

Trait PlatformWindowAttributes 

pub trait PlatformWindowAttributes:
    Any
    + Debug
    + Send
    + Sync {
    // Required method
    fn box_clone(&self) -> Box<dyn PlatformWindowAttributes>;
}

Required Methods

Implementations

Source

impl dyn PlatformWindowAttributes + '_

pub fn cast_ref<T: PlatformWindowAttributes>(&self) -> Option<&T>

Downcast to the backend concrete type.

Returns None if the object was not from that backend.

pub fn cast_mut<T: PlatformWindowAttributes>(&mut self) -> Option<&mut T>

Mutable downcast to the backend concrete type.

Returns None if the object was not from that backend.

pub fn cast<T: PlatformWindowAttributes>( self: Box<Self>, ) -> Result<Box<T>, Box<Self>>

Owned downcast to the backend concrete type.

Returns Err with self if the object was not from that backend.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors