pub trait PlatformWindowAttributes:
Any
+ Debug
+ Send
+ Sync {
// Required method
fn box_clone(&self) -> Box<dyn PlatformWindowAttributes>;
}Required Methods
fn box_clone(&self) -> Box<dyn PlatformWindowAttributes>
Implementations
Sourceimpl dyn PlatformWindowAttributes + '_
impl dyn PlatformWindowAttributes + '_
Sourcepub fn cast_ref<T: PlatformWindowAttributes>(&self) -> Option<&T>
pub fn cast_ref<T: PlatformWindowAttributes>(&self) -> Option<&T>
Downcast to the backend concrete type.
Returns None if the object was not from that backend.
Sourcepub fn cast_mut<T: PlatformWindowAttributes>(&mut self) -> Option<&mut T>
pub fn cast_mut<T: PlatformWindowAttributes>(&mut self) -> Option<&mut T>
Mutable downcast to the backend concrete type.
Returns None if the object was not from that backend.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".